/*
 * NAME:      cics_ccinx.h - COMMAREA structure definition for DFHCCINX
 *                           autoinstall user replacable program.
 *
 * VERSION:   1.1
 * COPYRIGHT:                                                        
 * 
 *   (C) COPYRIGHT International Business Machines Corp. 1993, 1997
 *   All Rights Reserved
 *   Licensed Materials - Property of IBM
 *  
 *   US Government Users Restricted Rights - Use, duplication or
 *   disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
 * 
 *                                                                   
 *
 *
 * DESCRIPTION:
 *      This file contains a description of the COMMAREA passed to the DFHCCINX
 *      user replacable program.  DFHCCINX is used to accept or reject
 *      Communication Definition (CD) autoinstall requests from remote CICS
 *      systems or IBM CICS clients.
 */

#if !defined(_CICS_CCINX_H)

#define _CICS_CCINX_H


#include <cicstype.h>            /* CICS supplied datatypes */

/*
 * OBJECT: Constants used to set the RequestType field of the COMMAREA.
 */

#define CICS_CCINX_REQUESTTYPE_INSTALL   0x00  /* Install operation required.*/
#define CICS_CCINX_REQUESTTYPE_DELETE    0x01  /* Uninstall operation reqd.  */

/*
 * DESCRIPTION:
 *
 *      CICS_CCINX_REQUESTYPE_INSTALL
 *              Indicates a Communications Definition (CD) entry is about
 *              to be installed (created).
 *
 *      CICS_CCINX_REQUESTTYPE_DELETE
 *              Indicates a Communications Definition (CD) entry is about
 *              to be uninstalled (deleted).
 */

/*
 * OBJECT: Constants used to set the SystemType field of the COMMAREA.
 */

#define CICS_CCINX_SYSTEMTYPE_CLIENT    0x00  /*Remote system is a CICS client*/
#define CICS_CCINX_SYSTEMTYPE_SERVER    0x01  /*Remote system is a CICS server*/

/*
 * DESCRIPTION:
 *
 *      CICS_CCINX_SYSTEMTYPE_CLIENT
 *              Indicates the Communications Definition (CD) entry is for an
 *              IBM CICS client.
 *
 *      CICS_CCINX_SYSTEMTYPE_SERVER 
 *              Indicates the Communications Definition (CD) entry is for a
 *              remote CICS server.
 */
/*
 * OBJECT: Constants used to set the RemoteSysSecurity field of the COMMAREA.
 */

#define CICS_CCINX_SECURITYTYPE_LOCAL     0x00   /* Local security */
#define CICS_CCINX_SECURITYTYPE_VERIFY    0x01   /* Verify security */
#define CICS_CCINX_SECURITYTYPE_TRUSTED   0x02   /* Trusted security */

#define CICS_CCINX_PSWD_CHECK_AND_DROP    0x00   /* Discard password */
#define CICS_CCINX_PSWD_IGNORE_AND_DROP   0x10   /* Discard password */
#define CICS_CCINX_PSWD_CHECK_AND_KEEP    0x20   /* Retain password */
#define CICS_CCINX_PSWD_IGNORE_AND_KEEP   0x30   /* Retain password */

/*
 * DESCRIPTION:
 *
 * The RemoteSysSecurity field is set using a logical OR (|) of a
 *   - SECURITYTYPE value (which is used to determine the RemoteSysSecurity
 *     attribute in the installed Communication Definition (CD) entry)
 * and a
 *   - PSWD value (which specifies how CICS should manage any passwords
 * received with userids on requests from the client/remote system).
 *
 *      CICS_CCINX_SECURITYTYPE_LOCAL
 *              Indicates the RemoteSysSecurity attribute in the installed
 *              CD entry is to be set to local.
 *
 *      CICS_CCINX_SECURITYTYPE_VERIFY
 *              Indicates the RemoteSysSecurity attribute in the installed
 *              CD entry is to be set to verify.
 *
 *      CICS_CCINX_SECURITYTYPE_TRUSTED
 *              Indicates the RemoteSysSecurity attribute in the installed
 *              CD entry is to be set to trusted.
 *
 *
 *      CICS_CCINX_PSWD_CHECK_AND_DROP
 *              Indicates that once CICS has verified a userid and a password
 *              received from the client/remote system, it should discard it.
 *              This means, if the request is routed on to another system,
 *              the password will not accompany the request.
 *
 *              This value is ignored if CICS_CCINX_SECURITYTYPE_VERIFY is not
 *              requested.
 *
 *      CICS_CCINX_PSWD_CHECK_AND_KEEP
 *              Indicates that once CICS has successfully verified a userid
 *              and a password received from the client/remote system,
 *              it should save it.
 *              This means both the userid and the password may accompany
 *              the request if it is routed on to another system.
 *              (The attribute OutboundUserIds in the CD entry for the
 *              system where the requests is routed to is used to determine
 *              whether the password is actually sent.)
 *
 *              This value is ignored if CICS_CCINX_SECURITYTYPE_VERIFY is not
 *              requested.
 *
 *      CICS_CCINX_PSWD_IGNORE_AND_DROP
 *              Indicates that if CICS receives a userid and a password
 *              with a request, it is not to verify the password and should
 *              treat the userid as if it were accompanied by a valid password.
 *              The password is discarded which means if the request is
 *              routed on to another system, the password will not accompany
 *              the request.
 *
 *              This value is ignored if CICS_CCINX_SECURITYTYPE_VERIFY is not
 *              requested.
 *
 *      CICS_CCINX_PSWD_IGNORE_AND_KEEP
 *              Indicates that if CICS receives a userid and a password
 *              with a request, it is not to verify the password and should
 *              treat the userid as if it were accompanied by a valid password.
 *              The password should be saved so it is available to
 *              forward to another system in that same way as the
 *              CICS_CCINX_PSWD_CHECK_AND_KEEP option.
 *
 *              This value is ignored if CICS_CCINX_SECURITYTYPE_VERIFY is not
 *              requested.
 *
 */
/*
 * OBJECT: Constants used to set the ConnectionType field of the COMMAREA
 */

#define CICS_CCINX_CTYPE_LOCALSNA        0x01  /* ConnectionType=local_sna   */
#define CICS_CCINX_CTYPE_CICSTCP         0x02  /* ConnectionType=cics_tcp    */
#define CICS_CCINX_CTYPE_PPCGATEWAY      0x04  /* ConnectionType=ppc_gateway */
#define CICS_CCINX_CTYPE_PPCTCP          0x08  /* ConnectionType=ppc_tcp     */
#define CICS_CCINX_CTYPE_DCERPC          0x10  /* ConnectionType=dce_rpc     */

/*
 * DESCRIPTION:
 *
 *      CICS_CCINX_CTYPE_LOCALSNA
 *              Indicates the CD entry is for a local SNA connection.
 *
 *      CICS_CCINX_CTYPE_CICSTCP
 *              Indicates the CD entry is for a CICS family TCP/IP connection,
 *              or for a Named Pipe (cicslterm) on Windows NT.
 *
 *      CICS_CCINX_CTYPE_PPCGATEWAY
 *              Indicates the CD entry is for a SNA connection using a PPC 
 *              gateway.
 *
 *      CICS_CCINX_CTYPE_PPCTCP
 *              Indicates the CD entry is for an Encina PPC TCP connection.
 *
 *      CICS_CCINX_CTYPE_DCERPC
 *              Indicates the CD entry is for a DCE RPC CICS client connection.
 */

/*
 * OBJECT: Constants used to set the ReturnCode field of the COMMAREA
 */

#define CICS_CCINX_RETURNCODE_OK         0x00  /* AutoInstall accepted.      */
#define CICS_CCINX_RETURNCODE_BADCP      0x01  /* Autoinstall accepted but
                                                * the code page is invalid   */
#define CICS_CCINX_RETURNCODE_REJECT     0x10  /* AutoInstall vetoed.        */

/*
 * DESCRIPTION:
 *
 *      CICS_CCINX_RETURNCODE_OK
 *              Indicates the autoinstall can proceed.
 *
 *      CICS_CCINX_RETURNCODE_BADCP
 *              Indicates the autoinstall can proceed.  However there is a
 *              problem with the code page so requests from the remote may fail.
 *              CICS will send an indicator to the remote system indicating 
 *              there is a problem with the code page.
 *
 *      CICS_CCINX_RETURNCODE_REJECT
 *              Indicates the autoinstall should be rejected.
 */

/*
 * OBJECT: Structure of the COMMAREA for DFHCCINX.
 */

struct CICS_CCINX_Parameters
{
    cics_sshort_t   Length;
    cics_ubyte_t    RequestType;
    cics_ubyte_t    SystemType;
    cics_sshort_t   ApplIdLength;
    cics_char_t     ApplId[9];
    cics_sshort_t   SysIdLength;
    cics_char_t     SysId[5];

    /* Data conversion information */
    cics_sshort_t   RemoteCodePageLength;
    cics_char_t     RemoteCodePage[80];
    cics_sshort_t   LocalCodePageLength;
    cics_char_t     LocalCodePage[80];
    cics_sshort_t   DefaultCodePageLength;
    cics_char_t     DefaultCodePage[80];

    /* Security information */
    cics_ubyte_t    RemoteSysSecurity;
    cics_sshort_t   LinkUserIdLength;
    cics_char_t     LinkUserId[9];

    /* Remote System Information */
    cics_ubyte_t    ConnectionType;
    cics_ulong_t    RemoteTCPAddress;
    cics_ushort_t   RemoteTCPPort;
    cics_char_t     RemoteSNALUName[9];

    /* Response */
    cics_ubyte_t    ReturnCode;

    /* DCE RPC Client Information */
    cics_ulong_t    RegionProtection;
    cics_ulong_t    ConnectionProtection;
};

/*
 * DESCRIPTION:
 *      This structure is passed to the DFHCCINX program when an install or 
 *      uninstall (delete) operation is being performed.
 *
 *      During installation, the program may change any of the following fields:
 *          - ApplId (and ApplIdLength)
 *          - SysId (and SysIdLength)
 *          - RemoteCodePage (and RemoteCodePageLength)
 *          - RemoteSysSecurity
 *          - LinkUserId (and LinkUserIdLength)
 *      or it may veto the installation totally by setting ReturnCode to
 *      CICS_CCINX_RETURNCODE_REJECT.  This program can not affect the outcome
 *      of an uninstall.
 *
 *      Below is a description of the fields in the COMMAREA for an install
 *      request.
 *
 *      Length           - The size of the CICS_CCINX_Parameters structure.
 *      RequestType      - Indicates if it is an install or an uninstall request
 *                         For an install request this would be set to
 *                         CICS_CCINX_REQUESTTYPE_INSTALL.
 *      SystemType       - Indicates if the install request is for a client or a
 *                         server.  For a client, this field is set to
 *                         CICS_CCINX_SYSTEMTYPE_CLIENT; for a server, its value
 *                         is CICS_CCINX_SYSTEMTYPE_SERVER.
 *      ApplIdLength     - Length of the ApplId in the ApplId field.
 *      ApplId           - ApplId of the remote system padded on the right with
 *                         NULLs (0x00).  The value returned in this field will
 *                         be set in the RemoteLUName attribute of the installed
 *                         CD entry.  Do not change this value if the CD entry
 *                         is for a CICS server.
 *      SysIdLength      - The length of the SYSID in the SysId field.
 *      SysId            - The four character key for the CD entry padded on the
 *                         right with NULLs (0x00).
 *      RemoteCodePageLength  - The length of the code page in RemoteCodePage.
 *      RemoteCodePage   - This is the code page received from the remote system
 *                         padded on the right with NULLs (0x00).
 *                         The value in this field when DFHCCINX returns to CICS
 *                         is used to set the RemoteCodePageTR attribute in the
 *                         installed CD entry.
 *      LocalCodePageLength   - The length of the code page in LocalCodePage.
 *      LocalCodePage    - This is the code page for the local region padded on
 *                         the right with NULLs (0x00).
 *      DefaultCodePageLength - The length of the code page in DefaultCodePage.
 *      DefaultCodePage  - This is the code page from the RemoteCodePageTR 
 *                         attribute of the default CD entry "" padded on the 
 *                         right with NULLs (0x00).
 *      RemoteSysSecurity - This indicates the type of security CICS should use
 *                         when receiving requests from the remote system.  
 *                         This starts as the value from the RemoteSysSecurity 
 *                         attribute of the default CD entry, "".  The value 
 *                         returned in this field by DFHCCINX is used to set 
 *                         the RemoteSysSecurity field in the installed CD 
 *                         entry and to determine how client passwords are
 *                         managed. If connectionType=CICS_CCINX_CTYPE_DCERPC,
 *                         this field should also be set.  The value
 *                         CICS_CCINX_SECURITYTYPE_TRUSTED indicates that CICS
 *                         will always accept the DCE principal and map it onto
 *                         a CICS userid for the request.  The value 
 *                         CICS_CCINX_SECURITYTYPE_VERIFY indicates that CICS
 *                         will accept a userid/password in preference to a DCE
 *                         principal, and validate these.  The value
 *                         CICS_CCINX_SECURITYTYPE_LOCAL indicates that CICS
 *                         will ignore any userid/password or DCE principal.
 *                         Trusted would normally be set for authenticated rpc
 *                         and verify for unauthenticated rpc communication.
 *      LinkUserIdLength - The length of the userid in LinkUserId.
 *      LinkUserId       - When DFHCCINX is called, this field contains the
 *                         LinkUserId attribute (padded on the right with NULLs
 *                         (0x00)) from the default CD entry, "".
 *                         The value returned to CICS by DFHCCINX is set in the
 *                         LinkUserId attribute of the installed CD entry.
 *      ConnectionType   - This indicates the type of connection that the
 *                         CCIN request was received on.
 *      RemoteTCPAddress - If connectionType=CICS_CCINX_CTYPE_CICSTCP, this 
 *                         field contains the TCP address of the remote system
 *                         (in network ordered byte format). If the connection
 *                         is a Named Pipe on Windows NT, this is 0x12345678.
 *                         If connectionType=CICS_CCINX_CTYPE_DCERPC, this 
 *                         field contains the TCP address of the client system
 *                         issuing the DCE RPC (in network ordered byte format).
 *      RemoteTCPPort    - If connectionType=CICS_CCINX_CTYPE_CICSTCP, this 
 *                         field contains the TCP port number of the remote 
 *                         system (in local host ordered byte format). If the
 *                         connection is a Named Pipe on Windows NT, this is 0.
 *                         If connectionType=CICS_CCINX_CTYPE_DCERPC, this 
 *                         field contains the TCP port number of the client 
 *                         system issuing the DCE RPC (in local host ordered 
 *                         byte format).
 *      RemoteSNALUName  - If connectionType=CICS_CCINX_CTYPE_LOCALSNA or
 *                         if connectionType=CICS_CCINX_CTYPE_PPCGATEWAY this 
 *                         field contains the SNA logical unit (LU) name of the
 *                         remote system.
 *      ReturnCode       - Set this field to indicate whether CICS is to proceed
 *                         with the installation request.
 *      RegionProtection - If connectionType=CICS_CCINX_CTYPE_DCERPC, this 
 *                         field contains the region runtime protection level
 *                         as defined in the Region Definition.  The values 
 *                         are rpc_c_protect_level_none, etc. as defined by
 *                         the DCE RPC documentation.
 *      ConnectionProtection - If connectionType=CICS_CCINX_CTYPE_DCERPC, this 
 *                         field is used by DFHCCINX to return the connection
 *                         runtime protection level of the rpc authentication
 *                         used between the client and CICS region.  The values
 *                         are rpc_c_protect_level_none, etc. as defined by
 *                         the DCE RPC documentation.  DFHCCINX should ensure
 *                         that the value returned is supported by the client,
 *                         otherwise the autoinstall will be rejected.
 *
 *      DFHCCINX cannot prevent an uninstall.  DFHCCINX is called so that it can
 *      maintain any private data or log messages.  Below is a description of
 *      the fields in the COMMAREA for an uninstall request.
 *
 *      Length           - The size of the CICS_CCINX_Parameters structure
 *      RequestType      - Indicates if it is an install or an uninstall
 *                         request. For an uninstall request this would be set
 *                         to CICS_CCINX_REQUESTTYPE_UNINSTALL.
 *      SystemType       - Indicates if the install request is for a client or a
 *                         server.  For a client, this field is set to
 *                         CICS_CCINX_SYSTEMTYPE_CLIENT; for a server, its value
 *                         is CICS_CCINX_SYSTEMTYPE_SERVER.
 *      ApplIdLength     - Length of the ApplId in the ApplId field.
 *      ApplId           - The value returned in this field is from the
 *                         RemoteLUName attribute of the CD entry.
 *      SysIdLength      - The length of the SYSID in the SysId field.
 *      SysId            - The four character key for the CD entry.
 *
 *      The rest of the fields in the uninstall COMMAREA are set to NULLs (Ox00)
 */

#endif /* _CICS_CCINX_H */

